@@ -41,6 +41,8 @@ G_BEGIN_DECLS
 
 GQuark              gp11_get_error_quark                    (void);
 
+GList*              gp11_list_ref_copy                      (GList *reflist);
+
 void                gp11_list_unref_free                    (GList *reflist);
 
 const gchar*        gp11_message_from_rv                    (CK_RV rv);
@@ -65,18 +67,17 @@ typedef struct GP11Attribute {
  * Used with var args in place of a length to denote that this type
  * of value follows.
  */
-enum {
-	GP11_BOOLEAN = -1,
-	GP11_ULONG = -2,
-	GP11_STRING = -3,
-	GP11_DATE = -4
-};
 
-#define GP11_INVALID -1UL
+#define GP11_BOOLEAN  ((gssize)-1)
+#define GP11_ULONG    ((gssize)-2)
+#define GP11_STRING   ((gssize)-3)
+#define GP11_DATE     ((gssize)-4)
+
+#define GP11_INVALID G_MAXULONG
 
 /* Used on varargs functions that should end with GP11_INVALID */
 #ifdef NOT_YET_SUPPORTED
-#define GP11_INVALID_TERMINATED __attribute__((__sentinel__(-1UL)))
+#define GP11_INVALID_TERMINATED __attribute__((__sentinel__(G_MAXULONG)))
 #else
 #define GP11_INVALID_TERMINATED
 #endif
@@ -286,6 +287,11 @@ GP11Module*           gp11_module_initialize                  (const gchar *path
                                                                gpointer reserved,
                                                                GError **err);
 
+gboolean              gp11_module_equal                       (gconstpointer module1,
+                                                               gconstpointer module2);
+
+guint                 gp11_module_hash                        (gconstpointer module);
+
 const gchar*          gp11_module_get_path                    (GP11Module *self);
 
 CK_FUNCTION_LIST_PTR  gp11_module_get_functions               (GP11Module *self);
@@ -426,6 +432,11 @@ struct _GP11SlotClass {
 
 GType               gp11_slot_get_type                      (void) G_GNUC_CONST;
 
+gboolean            gp11_slot_equal                         (gconstpointer slot1,
+                                                             gconstpointer slot2);
+
+guint               gp11_slot_hash                          (gconstpointer slot);
+
 GP11Module*         gp11_slot_get_module                    (GP11Slot *self);
 
 CK_SLOT_ID          gp11_slot_get_handle                    (GP11Slot *self);
@@ -441,6 +452,9 @@ GP11Mechanisms*     gp11_slot_get_mechanisms                (GP11Slot *self);
 GP11MechanismInfo*  gp11_slot_get_mechanism_info            (GP11Slot *self,
                                                              gulong mech_type);
 
+gboolean            gp11_slot_has_flags                     (GP11Slot *self,
+                                                             gulong flags);
+
 #if UNIMPLEMENTED
 
 gboolean            gp11_slot_init_token                    (GP11Slot *self, 
@@ -1260,6 +1274,11 @@ GList*              gp11_objects_from_handle_array          (GP11Slot *slot,
                                                              CK_OBJECT_HANDLE_PTR handles,
                                                              CK_ULONG n_handles);
 
+gboolean            gp11_object_equal                       (gconstpointer slot1,
+                                                             gconstpointer slot2);
+
+guint               gp11_object_hash                        (gconstpointer slot);
+
 GP11Module*         gp11_object_get_module                  (GP11Object *self);
 
 GP11Slot*           gp11_object_get_slot                    (GP11Object *self);
